@@ -81,6 +81,9 @@ class Plotter:
         optimal_min = lower_percentile - pad_amount
         optimal_max = upper_percentile + pad_amount
 
+        if optimal_min == optimal_max:
+            return None, None
+
         return optimal_min, optimal_max
 
     @staticmethod
@@ -94,10 +97,10 @@ class Plotter:
                 config[p] = config[p].replace({None: "''"}).apply(
                     ast.literal_eval).replace({'': None})
         
-        for p in ['labs', 'origin_file']:
+        for p in ['y_var_label', 'origin_file']:
             if p in config:
                 config[p] = config[p].replace({None: "[]"}).apply(
-                    ast.literal_eval)
+                    lambda x: ast.literal_eval(x) if '[' in x else x)
         return config
 
     @staticmethod
@@ -173,6 +176,14 @@ class Plotter:
         """ Plot based on the configuration from CSV """
         config.update(kwargs)
 
+        # Set the y_var as a list if it is a string
+        if isinstance(config['y_var'], str):
+            config['y_var'] = [config['y_var']]
+
+        # Set the labels if not provided
+        if not config.get('y_var_label', None):
+            config['y_var_label'] = config['y_var']
+
         # Apply the selected style
         self.apply_style(self.style)
         
@@ -183,9 +194,6 @@ class Plotter:
         
         plt.figure(figsize=Plotter._get_figure_size(
             config.get('aspect', 'wide')))
-        
-        if isinstance(config['y_var'], str):
-            config['y_var'] = [config['y_var']]
 
         # Only keep the columns that are present in the data
         config['x_var'] = config['x_var'] if config['x_var'] in data.columns else ''
@@ -197,8 +205,8 @@ class Plotter:
             plt.close()
             return
 
-        for y in config['y_var']:
-            sns.lineplot(data=data, x=config['x_var'], y=y,
+        for y, l in list(zip(config['y_var'], config['y_var_label'])):
+            sns.lineplot(data=data, x=config['x_var'], y=y, label=l,
                                 hue=config['hue'], style=config['style'], size=config['size'])
         
         if config.get('x_label', None):
